@@ -1,11 +1,11 @@
-/* -*- Mode: C; tab-width: 2; indent-tabs-mode: t; c-basic-offset: 2 -*- */
+/* -*- Mode: C; tab-width: 2;   indent-tabs-mode: space; c-basic-offset: 2 -*- */
 /* vi: set ts=2 sw=2: */
 /* dicfile.h
-   
+
    GJITEN : A JAPANESE DICTIONARY FOR GNOME
-  
+
    Copyright (C) 1999-2005 Botond Botyanszki <boti at rocketmail dot com>
-   
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published  by
    the Free Software Foundation; either version 2 of the License, or
@@ -24,7 +24,7 @@
 #ifndef __DICFILE_H__
 #define __DICFILE_H__
 
-#include <glib.h>
+#include <gtk/gtk.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -33,26 +33,29 @@
 typedef struct _GjitenDicfile GjitenDicfile;
 
 struct _GjitenDicfile {
-	gchar *path;
-	gchar *name;
-	gchar *mem;
-	int file;
-	gint status;
+  gchar *path;
+  gchar *name;
+  gchar *mem;
+  int file;
+  gint status;
   struct stat stat;
-	gint size;
+  gint size;
 };
 
 enum {
-	DICFILE_NOT_INITIALIZED,
-	DICFILE_BAD,
-	DICFILE_OK
+  DICFILE_NOT_INITIALIZED,
+  DICFILE_BAD,
+  DICFILE_OK
 };
 
 
-gboolean dicfile_is_utf8(GjitenDicfile *dicfile);
-gboolean dicfile_init(GjitenDicfile *dicfile);
-void dicfile_close(GjitenDicfile *dicfile);
-void dicfile_list_free(GSList *dicfile_list);
-gboolean dicfile_check_all(GSList *dicfile_list);
+GjitenDicfile *dicfile_new      (gchar *name,
+                                 gchar *path);
+void           dicfile_free     (GjitenDicfile *self);
+const gchar   *dicfile_init     (GjitenDicfile *dicfile);
+void           dicfile_close    (GjitenDicfile *dicfile);
+void           dicfile_list_free(GSList *dicfile_list);
+gboolean       dicfile_check_all(GSList *dicfile_list);
+const gchar   *dicfile_is_valid (GjitenDicfile *self);
 
 #endif
