@@ -1,9 +1,9 @@
-/* -*- Mode: C; tab-width: 2; indent-tabs-mode: t; c-basic-offset: 2 -*- */
+/* -*- Mode: C; tab-width: 2;   indent-tabs-mode: space; c-basic-offset: 2 -*- */
 /* vi: set ts=2 sw=2: */
 /* gjiten.h
 
    GJITEN : A GTK+/GNOME BASED JAPANESE DICTIONARY
-  
+
    Copyright (C) 1999 - 2005 Botond Botyanszki <boti@rocketmail.com>
 
    This program is free software; you can redistribute it and/or modify
@@ -24,20 +24,30 @@
 #ifndef __GJITEN_H__
 #define __GJITEN_H__
 
+#include "conf.h"
+#include "worddic.h"
+#include "kanjidic.h"
+
 typedef struct _GjitenApp GjitenApp;
 
 struct _GjitenApp {
-	WordDic *worddic;
-	KanjiDic *kanjidic;
-	GjitenConfig *conf;
-	GtkWidget *pref_dialog;
+  GjWorddicWindow *worddic;
+  GjKanjidicWindow *kanjidic;
+  GjitenConfig *conf;
 };
 
+GtkApplication * gjiten_new();
 
-void gjiten_start_kanjipad();
-void gjiten_create_about();
-void gjiten_display_manual();
-void gjiten_exit();
-void gjiten_clear_entry_box(gpointer entrybox);
+void gjiten_start_kanjipad(GSimpleAction *, GVariant *, void *);
+void gjiten_start_worddic(GtkApplication *);
+void gjiten_start_kanjidic(GtkApplication *);
+void gjiten_start_kanjidic_with_search(gunichar kanji);
+
+void gjiten_apply_fonts(GjitenApp * gjitenApp);
+
+void gjiten_display_manual(GtkWidget *parent_window_nullable,
+                           void      *data);
+
+void gjiten_quit_if_all_windows_closed();
 
 #endif
